==> haskell-rio-orphans-0.1.2.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-1Axn5e5b81KG9RmT5E3140
key:                  rio-orphans-0.1.2.0-1Axn5e5b81KG9RmT5E3140
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  35892bc808d55fd823b5948762deaca2
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/rio-orphans-0.1.2.0
hs-libraries:         HSrio-orphans-0.1.2.0-1Axn5e5b81KG9RmT5E3140
depends:
    base-4.15.0.0 exceptions-0.10.4
    fast-logger-3.0.5-6EsFwn4rgE63zTw5JDUjz9
    monad-control-1.0.2.3-8GJnf4t1yRaE6dz1CLjZVk
    monad-logger-0.3.36-2ysWZ4Sst2GP57Pk2pEs7
    resourcet-1.2.4.2-C19MLccVwM3ICk9gxUD8Z6
    rio-0.1.20.0-ByWzLPTHRVLBUddXzGrKYf
    transformers-base-0.4.5.2-77WQ8Nli3rGmT3I2iNwlr
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-IydRpbBV1OlLggNNKqte4q
key:                  rio-orphans-0.1.2.0-IydRpbBV1OlLggNNKqte4q
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  d98f268d5b484e3763e9be42b3a7d116
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/rio-orphans-0.1.2.0
hs-libraries:         HSrio-orphans-0.1.2.0-IydRpbBV1OlLggNNKqte4q
depends:
    base-4.15.0.0 exceptions-0.10.4
    fast-logger-3.0.5-DVqWAKpkUFNJQburYHnjM8
    monad-control-1.0.2.3-135QfWS56U73vJp0UY9qMK
    monad-logger-0.3.36-2zzvkYrRLYA2L6lLMnHWjw
    resourcet-1.2.4.2-DeH26qhPbHtGqmnagpMjR9
    rio-0.1.20.0-9IKJYfqTzYu1CgkDeZcdt6
    transformers-base-0.4.5.2-Bz6tJiZ3kA02bvHhlc5LaV
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
